Clean update ETC1 data utilities (take 2)

Change-Id: Idb84867cf1a701bd2f0ffff863fd78c3caf0739e
Reviewed-on: https://skia-review.googlesource.com/c/skia/+/217376
Reviewed-by: Greg Daniel <egdaniel@google.com>
Commit-Queue: Robert Phillips <robertphillips@google.com>
diff --git a/src/gpu/GrDataUtils.h b/src/gpu/GrDataUtils.h
index a3e0e34..bdcbd66 100644
--- a/src/gpu/GrDataUtils.h
+++ b/src/gpu/GrDataUtils.h
@@ -15,14 +15,11 @@
 bool GrFillBufferWithColor(GrPixelConfig config, int width, int height,
                            const SkColor4f& color, void* dest);
 
-struct ETC1Block {
-    uint32_t fHigh;
-    uint32_t fLow;
-};
+// TODO: consolidate all the backend-specific flavors of this method to this
+size_t GrETC1CompressedDataSize(int w, int h);
 
-int GrNumETC1Blocks(int w, int h);
-
-// Fill in 'blocks' with ETC1 blocks derived from 'color'
-void GrFillInETC1WithColor(const SkColor4f& color, void* blocks, int numBlocks);
+// Fill in 'dest' with ETC1 blocks derived from 'color'
+void GrFillInETC1WithColor(int width, int height,
+                           const SkColor4f& color, void* dest);
 
 #endif